==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/QGpCoreWave/src/RefractionProxy.h <==
/***************************************************************************
**
**  This file is part of QGpCoreWave.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2016-08-23
**  Copyright: 2016-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef REFRACTIONPROXY_H
#define REFRACTIONPROXY_H

#include <QGpCoreMath.h>

#include "RefractionCurve.h"
#include "QGpCoreWaveDLLExport.h"

namespace QGpCoreWave {

  class QGPCOREWAVE_EXPORT RefractionProxy : public CurveProxy
  {
    TRANSLATIONS("RefractionProxy")
  public:
    RefractionProxy() : CurveProxy() {_curve=0;}

    virtual QString tag() const {return "TravelTimeProxy";}

    virtual CurveProxy * clone() const {return new RefractionProxy;}

    CURVEPROXY_BASICDECLARATIONS
    CURVEPROXY_NAMEDECLARATIONS
    CURVEPROXY_LOGDECLARATIONS
    void average(const CurveProxy * o) {
      curve().average(static_cast<const RefractionProxy *>(o)->curve());
    }

    virtual int columnCount() const {return 4;}
    virtual QString columnName(int col) const;
    virtual QString columnUnit(int col) const;

    virtual QVariant columnValue(int sample, int col) const;
    virtual void setColumnValue(int sample, int col, const QVariant & value);

    virtual int xAxisColumn() const {return 0;}
    virtual int xAxisInversedColumn() const  {return -1;}
    virtual int yAxisColumn() const {return 1;}
    virtual int yAxisInversedColumn() const {return -1;}

    virtual QStringList columnFileTypes() const;
    virtual QVector<int> defaultColumnFileTypes() const;
    virtual QVector<int> savedColumns() const;

    virtual bool parse(ColumnTextIterator& it);

    void setCurve(RefractionCurve * c) {_curve=c;}
    const RefractionCurve& curve() const {return *_curve;}
    RefractionCurve& curve() {return *_curve;}
  private:
    RefractionCurve *_curve;
  };

} // namespace QGpCoreWave

#endif // REFRACTIONPROXY_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpCoreWave/src/RefractionProxy.h <==
/***************************************************************************
**
**  This file is part of QGpCoreWave.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2016-08-23
**  Copyright: 2016-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef REFRACTIONPROXY_H
#define REFRACTIONPROXY_H

#include <QGpCoreMath.h>

#include "RefractionCurve.h"
#include "QGpCoreWaveDLLExport.h"

namespace QGpCoreWave {

  class QGPCOREWAVE_EXPORT RefractionProxy : public CurveProxy
  {
    TRANSLATIONS("RefractionProxy")
  public:
    RefractionProxy() : CurveProxy() {_curve=0;}

    virtual QString tag() const {return "TravelTimeProxy";}

    virtual CurveProxy * clone() const {return new RefractionProxy;}

    CURVEPROXY_BASIC_DECLARATIONS(RefractionCurve)
    CURVEPROXY_ADVANCED_DECLARATIONS(RefractionProxy)
    CURVEPROXY_NAME_DECLARATIONS
    CURVEPROXY_LOG_DECLARATIONS

    int columnCount() const {return 4;}
    QString columnName(int col) const;
    QString columnUnit(int col) const;

    QVariant columnValue(int sample, int col) const;
    void setColumnValue(int sample, int col, const QVariant & value);

    int xAxisColumn() const {return 0;}
    int xAxisInverseColumn() const  {return -1;}
    int yAxisColumn() const {return 1;}
    int yAxisInverseColumn() const {return -1;}

    QStringList columnFileTypes() const;
    VectorList<int> defaultColumnFileTypes() const;
    VectorList<int> savedColumns() const;

    bool parse(ColumnTextIterator& it);
  private:
    CURVEPROXY_PRIVATE_DECLARATIONS(RefractionCurve, FactoryPoint)
  };

} // namespace QGpCoreWave

#endif // REFRACTIONPROXY_H
